#ifndef NT2_INCLUDE_FUNCTIONS_REPEAT_LOWER_HALF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REPEAT_LOWER_HALF_HPP_INCLUDED

#include <nt2/swar/include/functions/repeat_lower_half.hpp>

#endif
